@@ -58,7 +58,7 @@ def get_playlist(speaker, name):
 def print_list_header(prefix, name):
     spacer = "  "
     title = "{} {}".format(prefix, name)
-    underline = "=" * (len(title))
+    underline = "=" * len(title)
     print(spacer + title)
     print(spacer + underline)
 
@@ -276,8 +276,14 @@ def track(speaker, action, args, soco_function, use_local_speaker_list):
     else:
         output = speaker.get_current_track_info()
         if output["duration"] == "0:00:00":
-            # Assume it's a radio station
-            print("Playing {}".format(output["title"]))
+            if (
+                speaker.get_current_transport_info()["current_transport_state"]
+                != "PLAYING"
+            ):
+                print("Stream Stopped: No Track Playing")
+            else:
+                # Assume it's a radio stream
+                print("Playing Stream: {}".format(output["title"]))
         else:
             for item in sorted(output):
                 if item not in ["metadata", "uri", "album_art"]:
@@ -760,9 +766,99 @@ def save_queue(speaker, action, args, soco_function, use_local_speaker_list):
 @one_parameter
 def seek(speaker, action, args, soco_function, use_local_speaker_list):
     try:
-        speaker.seek(args[0])
+        time_point = int(convert_to_seconds(args[0]))
+        logging.info("Seek point is {}s".format(time_point))
+        hours = time_point // 3600
+        time_point = time_point - hours * 3600
+        minutes = time_point // 60
+        time_point = time_point - minutes * 60
+        seconds = time_point
+        seek_string = (
+            str(hours).zfill(2)
+            + ":"
+            + str(minutes).zfill(2)
+            + ":"
+            + str(seconds).zfill(2)
+        )
+        logging.info("Seek point is '{}'".format(seek_string))
+        speaker.seek(seek_string)
     except:
-        parameter_type_error(action, "HH:MM:SS on a seekable source")
+        parameter_type_error(action, "time value on a seekable source")
+        return False
+    return True
+
+
+@one_parameter
+def seek_forward(speaker, action, args, soco_function, use_local_speaker_list):
+    try:
+        # Calculate the time increment
+        increment = int(convert_to_seconds(args[0]))  # Integer number of seconds
+        logging.info("Seeking forward by {}s".format(increment))
+        current_position = speaker.get_current_track_info()["position"]
+        logging.info("Current playback position is '{}'".format(current_position))
+        inc_hours = increment // 3600
+        increment = increment - inc_hours * 3600
+        inc_minutes = increment // 60
+        increment = increment - inc_minutes * 60
+        inc_seconds = increment
+        current_position = current_position.split(":")
+        seconds = (int(current_position[2]) + inc_seconds) % 60
+        inc_minutes = inc_minutes + (int(current_position[2]) + inc_seconds) // 60
+        minutes = (int(current_position[1]) + inc_minutes) % 60
+        inc_hours = inc_hours + (int(current_position[1]) + inc_minutes) // 60
+        hours = int(current_position[0]) + inc_hours
+        seek_string = (
+            str(hours).zfill(2)
+            + ":"
+            + str(minutes).zfill(2)
+            + ":"
+            + str(seconds).zfill(2)
+        )
+        logging.info(
+            "Seeking forward to position '{}' ... might hit end of track".format(
+                seek_string
+            )
+        )
+        speaker.seek(seek_string)
+    except:
+        parameter_type_error(action, "time increment on a seekable source")
+        return False
+    return True
+
+
+@one_parameter
+def seek_back(speaker, action, args, soco_function, use_local_speaker_list):
+    try:
+        increment = int(convert_to_seconds(args[0]))  # Integer number of seconds
+        current_position = speaker.get_current_track_info()["position"]
+        if increment > int(convert_to_seconds(current_position)):
+            logging.info("Cannot seek beyond start of track ... seek to start instead")
+            speaker.seek("00:00:00")
+            return True
+        logging.info("Current playback position is '{}'".format(current_position))
+        logging.info("Seeking backward by {}s".format(increment))
+        inc_hours = increment // 3600
+        increment = increment - inc_hours * 3600
+        inc_minutes = increment // 60
+        increment = increment - inc_minutes * 60
+        inc_seconds = increment
+        current_position = current_position.split(":")
+        seconds = (int(current_position[2]) - inc_seconds) % 60
+        inc_minutes = inc_minutes - (int(current_position[2]) - inc_seconds) // 60
+        minutes = (int(current_position[1]) - inc_minutes) % 60
+        inc_hours = inc_hours - (int(current_position[1]) - inc_minutes) // 60
+        hours = int(current_position[0]) - inc_hours
+        seek_string = (
+            str(hours).zfill(2)
+            + ":"
+            + str(minutes).zfill(2)
+            + ":"
+            + str(seconds).zfill(2)
+        )
+        logging.info("Seeking backward to position '{}'".format(seek_string))
+        speaker.seek(seek_string)
+    except:
+        parameter_type_error(action, "time increment on a seekable source")
         return False
     return True
 
@@ -852,21 +948,26 @@ def line_in(speaker, action, args, soco_function, use_local_speaker_list):
             speaker.stop()
         elif source.lower() in ["on", "left_input"]:
             # Switch to the speaker's own line_in
+            logging.info("Switching to the speaker's own Line-In")
             speaker.switch_to_line_in()
             speaker.play()
         else:
             line_in_source = None
             if source.lower() == "right_input":
                 # We want the right-hand speaker of the stereo pair
+                logging.info("Looking for right-hand speaker")
                 line_in_source = get_right_hand_speaker(speaker)
             else:
                 # We want to use another speaker's input
                 if np == 2:  # Want to select the input of a stereo pair
                     the_input = args[1].lower()
                     if the_input == "right_input":
+                        logging.info("Using right-hand speaker's input")
+                        logging.info("Looking for right-hand speaker")
                         left_speaker = get_speaker(source, use_local_speaker_list)
                         line_in_source = get_right_hand_speaker(left_speaker)
                     elif the_input == "left_input":
+                        logging.info("Using left-hand speaker's input")
                         line_in_source = get_speaker(source, use_local_speaker_list)
                     else:
                         parameter_type_error(
@@ -875,10 +976,12 @@ def line_in(speaker, action, args, soco_function, use_local_speaker_list):
                         )
                         return False
                 else:
+                    logging.info("Using left-hand speaker's input")
                     line_in_source = get_speaker(source, use_local_speaker_list)
             if not line_in_source:
                 error_and_exit("Speaker or input '{}' not found".format(source))
                 return False
+            logging.info("Switching to Line-In and starting playback")
             speaker.switch_to_line_in(line_in_source)
             speaker.play()
     return True
@@ -1628,6 +1731,11 @@ actions = {
     "apq": SonosFunction(playlist_operations, "add_to_queue"),
     "pause_all": SonosFunction(operate_on_all, "pause"),
     "seek": SonosFunction(seek, "seek"),
+    "seek_to": SonosFunction(seek, "seek"),
+    "seek_forward": SonosFunction(seek_forward, "seek_forward"),
+    "sf": SonosFunction(seek_forward, "seek_forward"),
+    "seek_back": SonosFunction(seek_back, "seek_back"),
+    "sb": SonosFunction(seek_back, "seek_back"),
     "line_in": SonosFunction(line_in, ""),
     "bass": SonosFunction(eq, "bass"),
     "treble": SonosFunction(eq, "treble"),
@@ -1681,10 +1789,13 @@ actions = {
     "search_library": SonosFunction(search_library, ""),
     "sl": SonosFunction(search_library, ""),
     "search_artists": SonosFunction(search_artists, ""),
+    "search_artist": SonosFunction(search_artists, ""),
     "sart": SonosFunction(search_artists, ""),
     "search_albums": SonosFunction(search_albums, ""),
+    "search_album": SonosFunction(search_albums, ""),
     "salb": SonosFunction(search_albums, ""),
     "search_tracks": SonosFunction(search_tracks, ""),
+    "search_track": SonosFunction(search_tracks, ""),
     "st": SonosFunction(search_tracks, ""),
     "tracks_in_album": SonosFunction(tracks_in_album, ""),
     "tia": SonosFunction(tracks_in_album, ""),
