@@ -9,6 +9,7 @@ from .action_processor import process_action
 from .speakers import Speakers
 from .utils import (
     RewindableList,
+    check_args,
     configure_common_args,
     configure_logging,
     convert_to_seconds,
@@ -68,6 +69,14 @@ def main():
         docs()
         exit(0)
 
+    if len(args.parameters) == 0:
+        print("No parameters. Use 'sonos --help' for usage information")
+        exit(0)
+
+    message = check_args(args)
+    if message:
+        error_and_exit(message)
+
     configure_logging(args.log)
 
     use_local_speaker_list = args.use_local_speaker_list
@@ -75,6 +84,7 @@ def main():
         speaker_list = Speakers(
             network_threads=args.network_discovery_threads,
             network_timeout=args.network_discovery_timeout,
+            min_netmask=args.min_netmask,
         )
         if args.refresh_local_speaker_list or not speaker_list.load():
             logging.info("Start speaker discovery")
@@ -98,6 +108,11 @@ def main():
                     "wait_for",
                     "wait_until",
                     "seek",
+                    "seek_to",
+                    "seek_forward",
+                    "sf",
+                    "seek_back",
+                    "sb",
                     "sleep",
                     "sleep_timer",
                     "sleep_at",
@@ -123,9 +138,10 @@ def main():
     rewindable_sequences = RewindableList(sequences)
     loop_iterator = None
     sequence_pointer = 0
-    loop_pointer = (
-        -1
-    )  # There is a notional 'loop' action before the first command sequence
+
+    # There is a notional 'loop' action before the first command sequence
+    loop_pointer = -1
+
     loop_start_time = None
     for sequence in rewindable_sequences:
         try:
@@ -176,6 +192,7 @@ def main():
                     error_and_exit(
                         "Action 'loop_for' requires one parameter (check spaces around the ':' separator)"
                     )
+                loop_duration = 0
                 if loop_start_time is None:
                     loop_start_time = time.time()
                     try:
@@ -205,6 +222,7 @@ def main():
 
             # Special case: the 'loop_until' action
             if speaker_name.lower() == "loop_until":
+                loop_duration = 0
                 if len(sequence) != 2:
                     error_and_exit(
                         "Action 'loop_until' requires one parameter (check spaces around the ':' separator)"
@@ -238,6 +256,7 @@ def main():
 
             # Special case: the 'wait' action
             if speaker_name in ["wait", "wait_for"]:
+                duration = 0
                 if len(sequence) != 2:
                     error_and_exit(
                         "Action 'wait' requires 1 parameter (check spaces around the ':' separator)"
