@@ -34,8 +34,9 @@ class Speakers:
         self,
         save_directory=None,
         save_file=None,
-        network_threads=128,
-        network_timeout=2.0,
+        network_threads=256,
+        network_timeout=0.1,
+        min_netmask=24,
     ):
         self._save_directory = (
             save_directory
@@ -46,6 +47,7 @@ class Speakers:
         self.remove_deprecated_pickle_files()
         self._network_threads = network_threads
         self._network_timeout = network_timeout
+        self._min_netmask = min_netmask
         self._speakers = []
         self._networks = []
 
@@ -112,6 +114,14 @@ class Speakers:
     def network_timeout(self, timeout):
         self._network_timeout = timeout
 
+    @property
+    def min_netmask(self):
+        return self._min_netmask
+
+    @min_netmask.setter
+    def min_netmask(self, min_netmask):
+        self._min_netmask = min_netmask
+
     def save(self):
         """Saves the speaker list as a pickle file."""
         if self._speakers:
@@ -158,16 +168,22 @@ class Speakers:
         for adapter in adapters:
             for ip in adapter.ips:
                 if Speakers.is_ipv4_address(ip.ip):
-                    # Restrict to common domestic private IP ranges and sensible
-                    # netmasks. Experimental ... assumptions need to be tested.
-                    if (
-                        ip.ip.startswith("192.168.") or ip.ip.startswith("10.")
-                    ) and ip.network_prefix <= 24:
-                        nw = ipaddress.ip_network(
+                    network_ip = ipaddress.ip_network(ip.ip)
+                    if network_ip.is_private and not network_ip.is_loopback:
+                        # Constrain the size of network that will be searched
+                        if ip.network_prefix < self._min_netmask:
+                            logging.info(
+                                "Constraining netmask={} to {}".format(
+                                    ip.network_prefix, self._min_netmask
+                                )
+                            )
+                            ip.network_prefix = self._min_netmask
+                        network = ipaddress.ip_network(
                             ip.ip + "/" + str(ip.network_prefix), False
                         )
-                        ipv4_net_list.add(nw)
+                        ipv4_net_list.add(network)
         self._networks = list(ipv4_net_list)
+        logging.info("IPv4 networks to search: {}".format(ipv4_net_list))
         return ipv4_net_list
 
     def get_ip_search_list(self):
@@ -186,14 +202,19 @@ class Speakers:
         if s.connect_ex((ip, port)) == 0:
             return True
         else:
+            logging.debug(
+                "Socket connection to {}:{} timed out after {}s".format(
+                    ip, port, timeout
+                )
+            )
             return False
 
     @staticmethod
-    def get_sonos_device_data(ip_addr, soco_timeout):
+    def get_sonos_device_data(ip_addr):
         """Get information from a Sonos device"""
         try:
             speaker = soco.SoCo(str(ip_addr))
-            info = speaker.get_speaker_info(refresh=True, timeout=soco_timeout)
+            info = speaker.get_speaker_info(refresh=True)
             return SonosDevice(
                 speaker.household_id,
                 str(ip_addr),
@@ -202,19 +223,23 @@ class Speakers:
                 info["model_name"],
                 info["display_version"],
             )
-        except Exception as e:
-            # Probably not a Sonos device
+        except:
+            logging.info("Not a Sonos device: '{}'".format(ip_addr))
             return None
 
     @staticmethod
-    def discovery_worker(ip_set, socket_timeout, soco_timeout, sonos_devices):
+    def discovery_worker(ip_set, socket_timeout, sonos_devices):
         """Worker thread to pull IP addresses from a set, test if port 1400 is open,
         and if so pull down the Sonos device data. Return when the list is empty.
         """
-        while len(ip_set) > 0:
-            ip_addr = ip_set.pop()
+        # Avoid possible race condition
+        while True:
+            try:
+                ip_addr = ip_set.pop()
+            except KeyError:
+                break
             if Speakers.check_ip_and_port(str(ip_addr), 1400, socket_timeout):
-                device = Speakers.get_sonos_device_data(ip_addr, soco_timeout)
+                device = Speakers.get_sonos_device_data(ip_addr)
                 if device:
                     sonos_devices.append(device)
                     logging.info("Found Sonos device at: {}".format(device.ip_address))
@@ -222,15 +247,23 @@ class Speakers:
     def discover(self):
         """Discover the Sonos speakers on the network(s) to which
         this host is attached."""
+
         ip_list = self.get_ip_search_list()
         thread_list = []
         self._speakers = []
+
         # Disable SoCo caching to prevent problems caused by multiple households
         soco.core.zone_group_state_shared_cache.enabled = False
+
         # Create parallel threads to scan the IP range
         threads = self._network_threads
         if threads > len(ip_list):
             threads = len(ip_list)
+        logging.info("Searching {} IP addresses".format(len(ip_list)))
+        logging.info("Creating {} threads for network scan".format(threads))
+        logging.info(
+            "Using socket timeout of {}s for port scan".format(self._network_timeout)
+        )
         for _ in range(threads):
             try:
                 # Catch thread creation exceptions
@@ -239,18 +272,22 @@ class Speakers:
                     args=(
                         ip_list,
                         self._network_timeout,
-                        (self._network_timeout, self._network_timeout),
                         self._speakers,
                     ),
                 )
+                thread.start()
+                thread_list.append(thread)
             except RuntimeError:
+                logging.info(
+                    "Failed to start new thread no. {}".format(len(thread_list) + 1)
+                )
                 break
-            thread_list.append(thread)
-            thread.start()
-        logging.info("Created {} threads for network scan".format(len(thread_list)))
+
         # Wait for all threads to finish before returning
         for thread in thread_list:
             thread.join()
+        logging.info("All {} threads exited".format(len(thread_list)))
+
         # Finally, for each household ID, check that all zones have been recorded
         # using zone information obtained from Sonos
         households = []
@@ -259,10 +296,8 @@ class Speakers:
                 households.append(speaker.household_id)
                 try:
                     for zone in soco.SoCo(speaker.ip_address).all_zones:
-                        device = Speakers.get_sonos_device_data(
-                            zone.ip_address, self._network_timeout
-                        )
-                        if not device in self._speakers:
+                        device = Speakers.get_sonos_device_data(zone.ip_address)
+                        if device not in self._speakers:
                             logging.info(
                                 "Group discovery found additional speaker at {}".format(
                                     device.ip_address
