@@ -214,8 +214,6 @@ def sig_handler(signal_received, frame):
     logging.info("Caught signal, exiting.")
     print(" CTRL-C ... exiting.")
     # ToDo: Temporary for now; hard kill required to get out of 'wait_for_stopped'
-    #       Need to understand this.
-    #       Not tested on Windows
     if use_sigterm:
         os.kill(os.getpid(), SIGTERM)
     else:
@@ -272,7 +270,7 @@ def configure_logging(log_level):
             logging.basicConfig(format=log_format, level=logging.DEBUG)
         elif log_level == "info":
             logging.basicConfig(format=log_format, level=logging.INFO)
-        elif log_level == "warning":
+        elif log_level in ["warn", "warning"]:
             logging.basicConfig(format=log_format, level=logging.WARNING)
         elif log_level == "error":
             logging.basicConfig(format=log_format, level=logging.ERROR)
@@ -280,7 +278,7 @@ def configure_logging(log_level):
             logging.basicConfig(format=log_format, level=logging.CRITICAL)
         else:
             error_and_exit(
-                "--log takes one of: NONE, DEBUG, INFO, WARN, ERROR, CRITICAL"
+                "--log takes one of: NONE, DEBUG, INFO, WARN(ING), ERROR, CRITICAL"
             )
 
 
@@ -308,9 +306,10 @@ def get_speaker(name, local=False):
 
 def get_right_hand_speaker(left_hand_speaker):
     # Get the right-hand speaker of a stereo pair when the
-    # left-hand speaker name/IP is supplied
+    # left-hand speaker is supplied
     if not left_hand_speaker.is_visible:
         # If not visible, this is not a left-hand speaker
+        logging.info("Speaker is visible: not a left-hand speaker")
         return None
     else:
         # Find the speaker which is not visible, for which the
@@ -321,7 +320,13 @@ def get_right_hand_speaker(left_hand_speaker):
                 and not rh_speaker.is_visible
                 and "sub" not in rh_speaker.get_speaker_info()["model_name"].lower()
             ):
+                logging.info(
+                    "Found right-hand speaker: {} / {}".format(
+                        rh_speaker.player_name, rh_speaker.ip_address
+                    )
+                )
                 return rh_speaker
+        logging.info("Right-hand speaker not found")
         return None
 
 
@@ -332,16 +337,23 @@ def configure_common_args(parser):
         "--network-discovery-threads",
         "-t",
         type=int,
-        default=128,
-        help="Maximum number of threads used for Sonos network discovery",
+        default=256,
+        help="Maximum number of threads for Sonos network discovery",
     )
     parser.add_argument(
         "--network-discovery-timeout",
         "-n",
         type=float,
-        default=2.0,
+        default=1.0,
         help="Network timeout for Sonos device scan (seconds)",
     )
+    parser.add_argument(
+        "--min_netmask",
+        "-m",
+        type=int,
+        default=24,
+        help="Minimum netmask for Sonos device scan (integer 0-32)",
+    )
     parser.add_argument(
         "--version",
         "-v",
@@ -363,6 +375,23 @@ def configure_common_args(parser):
     )
 
 
+def check_args(args):
+    """Check values of parameters. Returns None, or an error message."""
+    message = ""
+    if not 0 <= args.min_netmask <= 32:
+        message = (
+            message + "\n    Option 'min_netmask' must be an integer between 0 and 32"
+        )
+    if not 0.0 <= args.network_discovery_timeout <= 60.0:
+        message = message + "\n    Option 'network_timeout' must be between 0.0 and 60s"
+    if not 1 <= args.network_discovery_threads <= 32000:
+        message = message + "\n    Option 'threads' must be between 1 and 32000"
+    if message == "":
+        return None
+    else:
+        return message
+
+
 path = os.path.expanduser("~") + "/.soco-cli/"
 filename = "saved_search.pickle"
 pathname = path + filename
